#!/usr/bin/env sh

# event-codes (change me)
event_ondock="ibm/hotkey LEN0268:00 00000080 00006030"
event_onundock="ibm/hotkey LEN0268:00 00000080 00004010"

# path variables
path_dock="/etc/acpi/events/tdock"
path_undock="/etc/acpi/events/tundock"
config_path="$HOME/.config/tdock"
config_file="$config_path/tdock.conf"

# Insp. from: https://feeding.cloud.geek.nz/posts/hooking-into-docking-undocking-events-to-run-scripts/
function usage {
   echo "tdock.sh <install|uninstall|config|isdocked>"
   exit 0
}

function read_config {
    if [ ! -f $config_file ]; then
        echo '[-] config not available (check: $config_file)'
        exit 1
    fi

    if [ $# -ne 1 ]; then
        exit 1
    fi
    echo $(cat $config_file | grep "^$1" | awk -F: '{print $2}')
}


# returns 1 if more than 1 screen is  connected
function isdocked {
    [ $(xrandr -q | grep " connected" | wc -l) -gt 1 ] && echo "1" ; exit 1
    echo "0"
    exit 0
}


# checking acpid paths and
function check_requirements {
    [ ! -d /etc/acpi/events ] && exit 1
    [ ! -f $(which systemctl) ] && exit 1
    [ ! -f $(which xrandr) ] && exit 1
}

function uninstall {
    echo "[-] uninstalling tdock..."

    [ -f $path_dock ] && sudo rm -rf $path_dock
    [ -f $path_undock ] && sudo rm -rf $path_undock
    [ -f $config_file ] && sudo rm -rf $config_path
    echo "[+] uninstall done"
    exit 0
}

function install {

    echo "[+] installing tdock..."
    echo "[*] Info: this tool requires sudo access at some point"

    # creating the directory for the config file
    mkdir -p $config_path

    # setup sample config file
    echo "docked:/path/to/docked/script.sh" | tee $config_file >/dev/null
    echo "undocked:/path/to/docked/script.sh" | tee -a $config_file >/dev/null

    echo "[*] Registering the acpi events..."

    # registering the dock event
    echo "event=${event_ondock}" | sudo tee $path_dock >/dev/null
    echo "action=su $(whoami) -c \"tdock.sh dock\"" | sudo tee -a $path_dock >/dev/null

    # registering the undock event
    echo "event=${event_onundock}"| sudo tee $path_undock >/dev/null
    echo "action=su $(whoami) -c \"tdock.sh undock\"" | sudo tee -a $path_undock >/dev/null

    echo "[*] Restarting the acpid service..."
    sudo systemctl restart acpid.service

}

function print_config {

    if [ ! -f $config_file ]; then
        echo '[-] config not available (check: $config_file)'
        exit 1
    fi

    echo "[*] config available under: $config_file"
    echo
    echo "Contains:"
    echo '```'
    cat $config_file
    echo '```'
}


# this function is called when the ACPI dock event is triggered
function dock {

    script_path=$(read_config docked)


    if [ -f "$script_path" ]; then
        exec $script_path
    fi
}


# this function is called when the ACPI undock event is triggered
function undock {

    script_path=$(read_config undocked)

    if [ -f "$script_path" ]; then
        exec $script_path
    fi

}


# having the wrong number of arguments
if [ "$#" -ne 1 ]; then
    usage
fi

# main menu
if [ "$1" = "install" ]; then
    install
elif [ "$1" = "uninstall" ]; then
    uninstall
elif [ "$1" = "isdocked" ]; then
    isdocked
elif [ "$1" = "dock" ]; then
    dock
elif [ "$1" = "undock" ]; then
    undock
elif [ "$1" = "config" ]; then
    print_config
fi
